======
README
======

TimeSide is a set of client and server side components for audio-enabling web sites and applications.
It includes a powerful DHTML-based interactive player, with support for time-marking.
The server side components provide generic APIs for easy transcoding, metadata embedding,
sound visualization and audio analysis.

Platforms
=========

TimeSide is intended to work on all Unix / Linux platforms.
MacOS X and Windows versions will soon be explorated.


Dependencies
============

For TimeSide Core::

    python (>= 2.4), python-xml, python-mutagen, python-imaging (>= 1.1.6),python-numpy,
    python-setuptools (>= 0.6b3), python-gst0.10, gstreamer0.10-plugins-base,
    gstreamer0.10-plugins-fluendo-mp3, gstreamer0.10-plugins-good

For TimeSide UI (optional)::

    * SoundManager 2 >= 2.91 : http://www.schillmania.com/projects/soundmanager2
    * jQuery => 1.2.6 : http://www.jquery.com
    * jsGraphics => 3.03 http://www.walterzorn.com/jsgraphics/jsgraphics_e.htm
    * See timeside/ui/README


Copyright
=========

Copyright (c) 2006, 2011 Parisson SARL (parisson.com),
Copyright (c) 2006, 2010 Samalyse SARL (samalyse.com),
All rights reserved.

Authors::

    Guillaume Pellerin <yomguy@parisson.com>
    Olivier Guilyardi  <olivier@samalyse.com>
    Paul Brossier      <piem@piem.org>


License
=======

TimeSide is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

TimeSide is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

See LICENSE for more details.


Install
=======

See INSTALL for full details.


Contact and Informations
========================

See http://code.google.com/p/timeside/
